module DDS(update, CLK, audio_CLK, out, st_sel, st_val,tone_sel, speed_sel, set_sel);
	//DDS Module 
	
	input update, CLK, audio_CLK;
	input [9:0] st_val; //value from the sine table
	input [3:0] tone_sel; //tone mapping
	input [1:0] speed_sel; //speed of the bars
	input set_sel; //specifies the octave of the tones
	output [7:0] st_sel; //index into the sine table
	output [15:0] out; //output audio signal


	reg[15:0] t0, tt0, tm0, N, ramp;
	reg[15:0] out_buff; //buffer the output
	reg[1:0] state, ramp_state;
	reg r_audio_CLK;

	parameter calc0= 0,  calc1= 1, pause= 2, done= 3;
	parameter ramp_up= 0, ramp_dip= 1, ramp_hold= 2, ramp_down= 3;
	
	wire [15:0] ramp_out, ramp_add, ramp_dim, ramp_dim_2; //variables for ramping the output tone
	wire [9:0] st_shift;
	wire unr, ovr;

	reg [15:0] p_inc, pm_inc, ramp_inc, ramp_dip_dec, ramp_down_dec, hold_str, hT;
	reg [3:0] tone_buff;
	reg [1:0] speed_buff, rnd;
	reg set_buff;

	assign out = out_buff; //buffeer the outut
	assign st_shift= st_val - 10'd255;
	
	//ramp the tone combinationally
	assign ramp_add= ramp + ramp_inc;
	assign ramp_dim= ramp - ramp_dip_dec;
	assign ramp_dim_2= ramp- ramp_down_dec;
	assign udr= ramp_dim_2[15]^ramp[15];
	assign ovr= ramp_add[15]^ramp[15];
	assign st_sel= (state == calc0)? tm0[15:8]: tt0[15:8];
	signed_mult m0 (ramp_out, ramp, {st_shift,6'b0});

	//select ramp up and hold time
	always @ (speed_buff) begin
		//the length of the tone is inversely proportional to the speed of the scan bar (the speed can be 1 of 3 settings)
		case(speed_buff)
			0: 
			begin
				ramp_inc= 16'h001F;
				ramp_dip_dec= 16'h0003;
				ramp_down_dec= 16'h0003;
				hold_str= 16'h03FF;
				hT= 16'd13000;
			end
			1:
			begin
				ramp_inc= 16'h002F;
				ramp_dip_dec= 16'h000F;
				ramp_down_dec= 16'h000F;
				hold_str= 16'h03FF;
				hT= 16'd8500;
			end		
			2:
			begin
				ramp_inc= 16'h003F;
				ramp_dip_dec= 16'h001F;
				ramp_down_dec= 16'h001F;
				hold_str= 16'h02FF;
				hT= 16'd5500;
			end
		endcase
	end
		
	//select base frequency (1 of 2)
	always @ (*) begin
		case(set_buff)
		0:
		begin
			case(tone_buff)
				//sine frequency
				0: p_inc= 16'd190;
				1: p_inc= 16'd225;
				2: p_inc= 16'd253;
				3: p_inc= 16'd301;
				4: p_inc= 16'd358;
				5: p_inc= 16'd379;
				6: p_inc= 16'd451;
				7: p_inc= 16'd506;
				8: p_inc= 16'd602;
				9: p_inc= 16'd716;
			endcase
			case(tone_buff)
				//modulating frequency
				1: pm_inc= 16'd502;
				2: pm_inc= 16'd597;
				3: pm_inc= 16'd670;
				4: pm_inc= 16'd797;
				5: pm_inc= 16'd948;
				6: pm_inc= 16'd1005;
				7: pm_inc= 16'd1195;
				8: pm_inc= 16'd1341;
				9: pm_inc= 16'd1595;
				10:pm_inc= 16'd1897;
			endcase
		end
		1:
		begin
			case(tone_buff)
				//sine frequency
				0: p_inc= 16'd268;
				1: p_inc= 16'd301;
				2: p_inc= 16'd338;
				3: p_inc= 16'd402;
				4: p_inc= 16'd451;
				5: p_inc= 16'd536;
				6: p_inc= 16'd602;
				7: p_inc= 16'd675;
				8: p_inc= 16'd804;
				9: p_inc= 16'd902;
			endcase
			case(tone_buff)
				//modulating frequency
				1: pm_inc= 16'd482;
				2: pm_inc= 16'd542;
				3: pm_inc= 16'd608;
				4: pm_inc= 16'd723;
				5: pm_inc= 16'd812;
				6: pm_inc= 16'd965;
				7: pm_inc= 16'd1084;
				8: pm_inc= 16'd1216;
				9: pm_inc= 16'd1446;
				10:pm_inc= 16'd1624;
			endcase
		end
	endcase
	end

	always @ (posedge CLK) begin
		r_audio_CLK <= audio_CLK;
		case (state) 	
		calc0:
		begin 
			//update
			t0 <= t0 + p_inc; 
			tm0 <= tm0 + pm_inc;
			tt0 <= t0 + {st_shift,1'b0};	
			
			case (ramp_state)
			ramp_up: //ramp the tone up
			begin
				if (~ovr) begin
					ramp <= ramp_add;
					state <= calc1;
					ramp_state <= ramp_up;
				end
				else begin
					ramp <= 16'h7FFF;
					state <= calc1;
					ramp_state <= ramp_dip;
				end
			end

			ramp_dip: //dip the tone down until it's at the peak
			begin
				if (ramp > hold_str) begin
					ramp <= ramp_dim;
					ramp_state <= ramp_dip;
					state <= calc1;
				end
				else begin
					//hold at peak
					ramp_state <= ramp_hold;
					state <= calc1;
					N <= 0;
				end
			end
									
			ramp_hold: //hold the tone constant
			begin
				if (N < hT) begin
					ramp <= ramp;
					state <= calc1;
					ramp_state <= ramp_hold;
					N <= N + 1;
				end
				else begin
					state <= calc1;
					ramp_state <= ramp_down;
				end			
			end	
			
				
			ramp_down: //ramp the tone down
			begin
				if (~udr) begin
					ramp <= ramp_dim_2;
					state <= calc1;
					ramp_state <= ramp_down;
				end
				else begin
					out_buff <= 16'd0;
					state <= done;
				end
			end
			endcase
		end
		
		calc1: //output the signal
		begin
		out_buff <= ramp_out;
		state <= pause;
		end

		pause: //wait for next audio cycle
		begin
			if (audio_CLK & ~r_audio_CLK) begin
				state <= calc0;
			end
			else begin
				state <= pause;
			end
		end
	
		done: //done outputting tone, wait for next trigger (update signal)
		begin 
			rnd <= rnd + 2'd1;
			if (update) begin
				state <= calc0;
				N <= 16'd0;
				ramp <= 16'd0;
				t0 <= 16'd0;
				tt0 <= 16'd0;
				tm0 <= 16'd256;
				tone_buff <= tone_sel + rnd;
				set_buff <= set_sel;
				speed_buff <= speed_sel;
				ramp_state <= ramp_up;
		end
			end
		endcase 
	end
		
endmodule