// --------------------------------------------------------------------
// --------------------------------------------------------------------
// Cornell University - ECE 5760
// Luke Ackerman (lba36), Weiqing Li (wi336)
// Final Project - Game of Life Music Generator
// --------------------------------------------------------------------
// --------------------------------------------------------------------
// Code based on VGA_640x480_m4k_DLADLA Template:
// Bruce R Land, Cornell University, Oct 2009
// Improved top module written by Adam Shapiro Oct 2009
// --------------------------------------------------------------------
// --------------------------------------------------------------------


module VGA_640x480_m4k_CA (
    // Clock Input
    input         CLOCK_27,    // 27 MHz
    input         CLOCK_50,    // 50 MHz
    input         EXT_CLOCK,   // External Clock
    // Push Button
    input  [3:0]  KEY,         // Pushbutton[3:0]
    // DPDT Switch
    input  [17:0] SW,          // Toggle Switch[17:0]
    // 7-SEG Display
    output [6:0]  HEX0,        // Seven Segment Digit 0
    output [6:0]  HEX1,        // Seven Segment Digit 1
    output [6:0]  HEX2,        // Seven Segment Digit 2
    output [6:0]  HEX3,        // Seven Segment Digit 3
    output [6:0]  HEX4,        // Seven Segment Digit 4
    output [6:0]  HEX5,        // Seven Segment Digit 5
    output [6:0]  HEX6,        // Seven Segment Digit 6
    output [6:0]  HEX7,        // Seven Segment Digit 7
    // LED
    output [8:0]  LEDG,        // LED Green[8:0]
    output [17:0] LEDR,        // LED Red[17:0]
    // UART
    output        UART_TXD,    // UART Transmitter
    input         UART_RXD,    // UART Receiver
    // IRDA
    output        IRDA_TXD,    // IRDA Transmitter
    input         IRDA_RXD,    // IRDA Receiver
    // SDRAM Interface
    inout  [15:0] DRAM_DQ,     // SDRAM Data bus 16 Bits
    output [11:0] DRAM_ADDR,   // SDRAM Address bus 12 Bits
    output        DRAM_LDQM,   // SDRAM Low-byte Data Mask 
    output        DRAM_UDQM,   // SDRAM High-byte Data Mask
    output        DRAM_WE_N,   // SDRAM Write Enable
    output        DRAM_CAS_N,  // SDRAM Column Address Strobe
    output        DRAM_RAS_N,  // SDRAM Row Address Strobe
    output        DRAM_CS_N,   // SDRAM Chip Select
    output        DRAM_BA_0,   // SDRAM Bank Address 0
    output        DRAM_BA_1,   // SDRAM Bank Address 0
    output        DRAM_CLK,    // SDRAM Clock
    output        DRAM_CKE,    // SDRAM Clock Enable
    // Flash Interface
    inout  [7:0]  FL_DQ,       // FLASH Data bus 8 Bits
    output [21:0] FL_ADDR,     // FLASH Address bus 22 Bits
    output        FL_WE_N,     // FLASH Write Enable
    output        FL_RST_N,    // FLASH Reset
    output        FL_OE_N,     // FLASH Output Enable
    output        FL_CE_N,     // FLASH Chip Enable
    // SRAM Interface
    inout  [15:0] SRAM_DQ,     // SRAM Data bus 16 Bits
    output [17:0] SRAM_ADDR,   // SRAM Address bus 18 Bits
    output        SRAM_UB_N,   // SRAM High-byte Data Mask 
    output        SRAM_LB_N,   // SRAM Low-byte Data Mask 
    output        SRAM_WE_N,   // SRAM Write Enable
    output        SRAM_CE_N,   // SRAM Chip Enable
    output        SRAM_OE_N,   // SRAM Output Enable
    // ISP1362 Interface
    inout  [15:0] OTG_DATA,    // ISP1362 Data bus 16 Bits
    output [1:0]  OTG_ADDR,    // ISP1362 Address 2 Bits
    output        OTG_CS_N,    // ISP1362 Chip Select
    output        OTG_RD_N,    // ISP1362 Write
    output        OTG_WR_N,    // ISP1362 Read
    output        OTG_RST_N,   // ISP1362 Reset
    output        OTG_FSPEED,  // USB Full Speed, 0 = Enable, Z = Disable
    output        OTG_LSPEED,  // USB Low Speed,  0 = Enable, Z = Disable
    input         OTG_INT0,    // ISP1362 Interrupt 0
    input         OTG_INT1,    // ISP1362 Interrupt 1
    input         OTG_DREQ0,   // ISP1362 DMA Request 0
    input         OTG_DREQ1,   // ISP1362 DMA Request 1
    output        OTG_DACK0_N, // ISP1362 DMA Acknowledge 0
    output        OTG_DACK1_N, // ISP1362 DMA Acknowledge 1
    // LCD Module 16X2
    inout  [7:0]  LCD_DATA,    // LCD Data bus 8 bits
    output        LCD_ON,      // LCD Power ON/OFF
    output        LCD_BLON,    // LCD Back Light ON/OFF
    output        LCD_RW,      // LCD Read/Write Select, 0 = Write, 1 = Read
    output        LCD_EN,      // LCD Enable
    output        LCD_RS,      // LCD Command/Data Select, 0 = Command, 1 = Data
    // SD Card Interface
    inout         SD_DAT,      // SD Card Data
    inout         SD_DAT3,     // SD Card Data 3
    inout         SD_CMD,      // SD Card Command Signal
    output        SD_CLK,      // SD Card Clock
    // I2C
    inout         I2C_SDAT,    // I2C Data
    output        I2C_SCLK,    // I2C Clock
    // PS2
    input         PS2_DAT,     // PS2 Data
    input         PS2_CLK,     // PS2 Clock
    // USB JTAG link
    input         TDI,         // CPLD -> FPGA (data in)
    input         TCK,         // CPLD -> FPGA (clk)
    input         TCS,         // CPLD -> FPGA (CS)
    output        TDO,         // FPGA -> CPLD (data out)
    // VGA
    output        VGA_CLK,     // VGA Clock
    output        VGA_HS,      // VGA H_SYNC
    output        VGA_VS,      // VGA V_SYNC
    output        VGA_BLANK,   // VGA BLANK
    output        VGA_SYNC,    // VGA SYNC
    output [9:0]  VGA_R,       // VGA Red[9:0]
    output [9:0]  VGA_G,       // VGA Green[9:0]
    output [9:0]  VGA_B,       // VGA Blue[9:0]
    // Ethernet Interface
    inout  [15:0] ENET_DATA,   // DM9000A DATA bus 16Bits
    output        ENET_CMD,    // DM9000A Command/Data Select, 0 = Command, 1 = Data
    output        ENET_CS_N,   // DM9000A Chip Select
    output        ENET_WR_N,   // DM9000A Write
    output        ENET_RD_N,   // DM9000A Read
    output        ENET_RST_N,  // DM9000A Reset
    input         ENET_INT,    // DM9000A Interrupt
    output        ENET_CLK,    // DM9000A Clock 25 MHz
    // Audio CODEC
    inout         AUD_ADCLRCK, // Audio CODEC ADC LR Clock
    input         AUD_ADCDAT,  // Audio CODEC ADC Data
    inout         AUD_DACLRCK, // Audio CODEC DAC LR Clock
    output        AUD_DACDAT,  // Audio CODEC DAC Data
    inout         AUD_BCLK,    // Audio CODEC Bit-Stream Clock
    output        AUD_XCK,     // Audio CODEC Chip Clock
    // TV Decoder
    input  [7:0]  TD_DATA,     // TV Decoder Data bus 8 bits
    input         TD_HS,       // TV Decoder H_SYNC
    input         TD_VS,       // TV Decoder V_SYNC
    output        TD_RESET,    // TV Decoder Reset
    // GPIO
    inout  [35:0] GPIO_0,      // GPIO Connection 0
    inout  [35:0] GPIO_1       // GPIO Connection 1
);

   //Turn off all displays.
   assign HEX0 = 7'h7F;
   assign HEX1 = 7'h7F;
   assign HEX2 = 7'h7F;
   assign HEX3 = 7'h7F;
   assign HEX4 = 7'h7F;
   assign HEX5 = 7'h7F;
   assign HEX6 = 7'h7F;
   assign HEX7 = 7'h7F;
   
   //Set all GPIO to tri-state.
   assign GPIO_0 = 36'hzzzzzzzzz;
   assign GPIO_1 = 36'hzzzzzzzzz;
   //Disable Ethernet.
   assign ENET_CLK   = 1'b0;
   assign ENET_CS_N  = 1'b1;
   assign ENET_CMD   = 1'b0;
   assign ENET_DATA  = 16'hzzzz;
   assign ENET_RD_N  = 1'b1;
   assign ENET_RST_N = 1'b1;
   assign ENET_WR_N  = 1'b1;

   //Disable flash.
   assign FL_ADDR  = 22'h0;
   assign FL_CE_N  = 1'b1;
   assign FL_DQ    = 8'hzz;
   assign FL_OE_N  = 1'b1;
   assign FL_RST_N = 1'b1;
   assign FL_WE_N  = 1'b1;

   //Disable OTG.
   assign OTG_ADDR    = 2'h0;
   assign OTG_CS_N    = 1'b1;
   assign OTG_DACK0_N = 1'b1;
   assign OTG_DACK1_N = 1'b1;
   assign OTG_FSPEED  = 1'b1;
   assign OTG_DATA    = 16'hzzzz;
   assign OTG_LSPEED  = 1'b1;
   assign OTG_RD_N    = 1'b1;
   assign OTG_RST_N   = 1'b1;
   assign OTG_WR_N    = 1'b1;
   
	//Enable SRAM 
	assign SRAM_OE_N = 1'b0;
	assign SRAM_UB_N = 1'b0;
	assign SRAM_LB_N = 1'b0;
	assign SRAM_CE_N = 1'b0;


   //Disable all other peripherals.
   //assign I2C_SCLK = 1'b0;
   assign IRDA_TXD = 1'b0;
   //assign TD_RESET = 1'b0;
   assign TDO = 1'b0;
   assign UART_TXD = 1'b0;
   
//////////////////// VGA Controller ////////////////////
wire	VGA_CTRL_CLK;
wire	AUD_CTRL_CLK;
wire	DLY_RST;

assign	TD_RESET	=	1'b1;	//	Allow 27 MHz
assign	AUD_XCK		=	AUD_CTRL_CLK;

Reset_Delay	r0 (.iCLK(CLOCK_50),.oRESET(DLY_RST));

//create VGA and Audio clocks
VGA_Audio_PLL  p1 (.areset(~DLY_RST),.inclk0(CLOCK_27),.c0(VGA_CTRL_CLK),.c1(AUD_CTRL_CLK),.c2(VGA_CLK));

VGA_Controller u1 (	//	Host Side
					.iCursor_RGB_EN(4'b0111),
					.oAddress(mVGA_ADDR),
					.oCoord_X(Coord_X),
					.oCoord_Y(Coord_Y),
					.iRed(mVGA_Rcbs),
					.iGreen(mVGA_Gcbs),
					.iBlue(mVGA_Bcbs),
					//	VGA Side
					.oVGA_R(VGA_R),
					.oVGA_G(VGA_G),
					.oVGA_B(VGA_B),
					.oVGA_H_SYNC(VGA_HS),
					.oVGA_V_SYNC(VGA_VS),
					.oVGA_SYNC(VGA_SYNC),
					.oVGA_BLANK(VGA_BLANK),
					//	Control Signal
					.iCLK(VGA_CTRL_CLK),
					.iRST_N(DLY_RST)	
					);

//Raw VGA signals (before adding UI)
wire [9:0]	mVGA_R;	
wire [9:0]	mVGA_G;
wire [9:0]	mVGA_B;

wire [18:0]	mVGA_ADDR;			//video memory address
wire [9:0]  Coord_X, Coord_Y;	//display coods

wire r_on,g_on,b_on; //used for enabling or disabling colors from other modules

//Draw Automaton & GUI
//Coarsen the pixel mapping so that a 4x4 block = 1 cell, but only use the 3x3 and the extra serves as a border (always black, 10'd0)
assign mVGA_R = ((Coord_X[1:0]==2'd1) | (Coord_Y[1:0]==2'd3)) ? 10'b0 : (r_on) ? ({10{disp_bit}}) : 10'b0;
assign mVGA_G = ((Coord_X[1:0]==2'd1) | (Coord_Y[1:0]==2'd3)) ? 10'b0 : (g_on) ? ({10{disp_bit}}) : 10'b0;
assign mVGA_B = ((Coord_X[1:0]==2'd1) | (Coord_Y[1:0]==2'd3)) ? 10'b0 : (b_on) ? ({10{disp_bit}}) : 10'b0;

//////////////////// Draw Cursor ////////////////////
//Pass in raw VGA signals and add cursor at (cur_x,cur_y)
//"c" at end of mVGA indicates the cursor has been added
wire [9:0] mVGA_Rc, mVGA_Gc, mVGA_Bc, cur_x, cur_y;
MakeCursor mc
(
	.vga_x(Coord_X),
	.vga_y(Coord_Y),
	.cur_x(cur_x-10'd1),
	.cur_y(cur_y),
	.mVGA_R(mVGA_R),
	.mVGA_G(mVGA_G),
	.mVGA_B(mVGA_B),
	.mVGA_Rc(mVGA_Rc),
	.mVGA_Gc(mVGA_Gc),
	.mVGA_Bc(mVGA_Bc)
);

//////////////////// Draw Border ////////////////////
//Pass in raw VGA signals and draw border around the edges of the screen
//"b" at end of mVGA indicates the border has been added
wire [9:0] mVGA_Rcb, mVGA_Gcb, mVGA_Bcb;
MakeBorder mb
(
	.vga_x(Coord_X),
	.vga_y(Coord_Y),
	.xmin(xmin),
	.xmax(xmax),
	.ymin(ymin),
	.ymax(ymax),
	.mVGA_R(mVGA_Rc),
	.mVGA_G(mVGA_Gc),
	.mVGA_B(mVGA_Bc),
	.mVGA_Rb(mVGA_Rcb),
	.mVGA_Gb(mVGA_Gcb),
	.mVGA_Bb(mVGA_Bcb),
	.play(play)
);

//////////////////// Highlight Row ////////////////////
//Highlight 3 rows of cells (row_y0, row_y1, row_y2) using r_on, g_on and b_on
HighlightRow hc(
	//.row_y(7'd60),
	.row_y0(ybar0[8:2]),
	.row_y1(ybar1[8:2]),
	.row_y2(ybar2[8:2]),
	.vga_y(Coord_Y),
	.r_on(r_on),
	.g_on(g_on),
	.b_on(b_on),
);

//////////////////// Draw Scan Bar ////////////////////
//Pass in raw VGA signals draw a scan bar and have it scan at a rate specified by period
//scan bar 0
//"s0" at end of mVGA indicates that scan bar 0 has been added
wire [9:0] mVGA_Rcbs0, mVGA_Gcbs0, mVGA_Bcbs0;
wire [8:0] ybar0; //position of bar 0
wire en0; //enable for bar 0
wire [23:0] period0;
MakeScanBar msb0(
	.CLK(VGA_CTRL_CLK),
	.reset(reset),
	.period(period0),
	.vga_y(Coord_Y),
	.ymax(ymax),
	.ymin(ymin),
	.vga_x(Coord_X),
	.xmax(xmax),
	.xmin(xmin),
	.mVGA_R(mVGA_Rcb),
	.mVGA_G(mVGA_Gcb),
	.mVGA_B(mVGA_Bcb),
	.mVGA_Rs(mVGA_Rcbs0),
	.mVGA_Gs(mVGA_Gcbs0),
	.mVGA_Bs(mVGA_Bcbs0),
	.ybar(ybar0),
	.barR(10'd0),
	.barG(10'd1023),
	.barB(10'd1023),
	.en(en0),
	.mode(tone_mode)
);	

//scan bar 1
//"s1" at end of mVGA indicates that scan bar 1 has been added
wire [9:0] mVGA_Rcbs1, mVGA_Gcbs1, mVGA_Bcbs1;
wire [8:0] ybar1; //position of bar 1
wire en1; //enable for bar 1
wire [23:0] period1;
MakeScanBar msb1(
	.CLK(VGA_CTRL_CLK),
	.reset(reset),
	.period(period1),
	.vga_y(Coord_Y),
	.ymax(ymax),
	.ymin(ymin),
	.vga_x(Coord_X),
	.xmax(xmax),
	.xmin(xmin),
	.mVGA_R(mVGA_Rcbs0),
	.mVGA_G(mVGA_Gcbs0),
	.mVGA_B(mVGA_Bcbs0),
	.mVGA_Rs(mVGA_Rcbs1),
	.mVGA_Gs(mVGA_Gcbs1),
	.mVGA_Bs(mVGA_Bcbs1),
	.ybar(ybar1),
	.barR(10'd1023),
	.barG(10'd1023),
	.barB(10'd0),
	.en(en1),
	.mode(tone_mode)
);	

//scan bar 2
//"s2" at end of mVGA indicates that scan bar 2 has been added
wire [9:0] mVGA_Rcbs, mVGA_Gcbs, mVGA_Bcbs;
wire [8:0] ybar2; //position of bar 2
wire en2; //enable for bar 2
wire [23:0] period2;
MakeScanBar msb2(
	.CLK(VGA_CTRL_CLK),
	.reset(reset),
	.period(period2),
	.vga_y(Coord_Y),
	.ymax(ymax),
	.ymin(ymin),
	.vga_x(Coord_X),
	.xmax(xmax),
	.xmin(xmin),
	.mVGA_R(mVGA_Rcbs1),
	.mVGA_G(mVGA_Gcbs1),
	.mVGA_B(mVGA_Bcbs1),
	.mVGA_Rs(mVGA_Rcbs),
	.mVGA_Gs(mVGA_Gcbs),
	.mVGA_Bs(mVGA_Bcbs),
	.ybar(ybar2),
	.barR(10'd1023),
	.barG(10'd0),
	.barB(10'd1023),
	.en(en2),
	.mode(tone_mode)
);	

//////////////////// M4K Memory ////////////////////
//port b is dedicated to the VGA controller for reading out to the screen
//port a is dedicated to the GOL state machine for updating the automaton
wire mem_bit ; //current data from m4k to VGA
reg disp_bit ; // registered data from m4k to VGA
vga_buffer display(
	.address_a (m4k_addr), 
	.address_b ({(Coord_Y[8:2]),(Coord_X[9:2]+8'd1)}), // vga current address
	.clock_a (VGA_CTRL_CLK),
	.clock_b (VGA_CTRL_CLK),
	.data_a (m4k_in), //data into memory
	.data_b (1'b0), // never write on port b
	.wren_a (m4k_we),
	.wren_b (1'b0), // never write on port b
	.q_a (m4k_out), //data out of memory
	.q_b (mem_bit) ); // data used to update VGA
		
// Read memory out to VGA display
always @ (negedge VGA_CTRL_CLK)
begin
	// register the m4k output for better timing on VGA
	// negedge seems to work better than posedge
	disp_bit <= mem_bit;
end

////////////////////NIOS CPU////////////////////
assign LCD_ON = 1'b1;
NIOS NIOS_inst
(
	//CLK, RESET
	.clk                            (CPU_CLK),
	.reset_n                        (KEY[0]),

	//SDRAM IO
	.zs_addr_from_the_sdram(DRAM_ADDR),
	.zs_ba_from_the_sdram({DRAM_BA_1, DRAM_BA_0}),
	.zs_cas_n_from_the_sdram(DRAM_CAS_N),
	.zs_cke_from_the_sdram(DRAM_CKE),
	.zs_cs_n_from_the_sdram(DRAM_CS_N),
	.zs_dq_to_and_from_the_sdram(DRAM_DQ),
	.zs_dqm_from_the_sdram({DRAM_UDQM, DRAM_LDQM}),
	.zs_ras_n_from_the_sdram(DRAM_RAS_N),
	.zs_we_n_from_the_sdram(DRAM_WE_N),
	
	//LCD IO
	.LCD_E_from_the_lcd_0(LCD_EN),
	.LCD_RS_from_the_lcd_0(LCD_RS),
	.LCD_RW_from_the_lcd_0(LCD_RW),
	.LCD_data_to_and_from_the_lcd_0(LCD_DATA),
	
	//SRAM
	.out_port_from_the_sram_we_n(SRAM_WE_N_cpu),
	.out_port_from_the_sram_dq(SRAM_DQ_cpu),
	.out_port_from_the_sram_addr(SRAM_ADDR_cpu),
	
	//P2S Controller
	.in_port_to_the_ps2_event_type(newEvent),
	.in_port_to_the_new_event_ready(new_event_ready),
    .out_port_from_the_event_has_been_read(event_has_been_read),
	
	//Cursor Control
	.out_port_from_the_cur_x(cur_x),
    .out_port_from_the_cur_y(cur_y),
	
	//Play Control
	.out_port_from_the_play(play),
	.out_port_from_the_period_gol(period_gol),
	
	//Drawing New Objects
	.out_port_from_the_obj(obj),
	
	//Control Scan Bars
	.out_port_from_the_en0(en0),
	.out_port_from_the_en1(en1),
	.out_port_from_the_en2(en2),
	.out_port_from_the_period0(period0),
	.out_port_from_the_period1(period1),
	.out_port_from_the_period2(period2),
	.out_port_from_the_speed0(speed0),
	.out_port_from_the_speed1(speed1),
	.out_port_from_the_speed2(speed2),
	
	//Audio Mode
	.out_port_from_the_tone_mode(tone_mode),
	.out_port_from_the_set_sel0(set_sel0),
	.out_port_from_the_set_sel1(set_sel1),
	.out_port_from_the_set_sel2(set_sel2)
	
);

assign LEDR[2:0] = tone_mode;
wire [2:0] tone_mode;
wire CPU_CLK;
sdram_pll neg_3ns (CLOCK_50, DRAM_CLK, CPU_CLK);

////////////////////Keyboard Controller////////////////////

wire        wKeyboardEventReady;
wire [7:0]  wKeyboardEventType;
Keyboard_Controller kc
(
	.iPS2_CLK(PS2_CLK), // PS2 clock input (20~30KHz)
	.iPS2_DAT(PS2_DAT), // PS2 data input
	.iCLK(CPU_CLK), // System clock
	.iRESET(reset), // System reset
	.oEventReady(wKeyboardEventReady), // Event has been read from keyboard
	.oEventType(wKeyboardEventType) // Which event was read
);

wire event_has_been_read;
reg [7:0] newEvent;
reg new_event_ready;
always @ (posedge CPU_CLK) begin
	if (event_has_been_read) begin
		//Clear the registers in preparation for a new keyboard event
		new_event_ready <= 1'b0;
		newEvent <= 8'b0;
	end
	else if (wKeyboardEventReady) begin
		//Signal to the processor that a new event is ready for reading
		new_event_ready <= 1'b1;
		//Store the event
		newEvent <= wKeyboardEventType;
	end
end

//////////////////// Game of Life Automaton ////////////////////
//Boundars of the screen
parameter xmax = 8'd158, xmin = 8'd1, ymin= 7'd1, ymax = 7'd119;

wire [23:0] period_gol; //controls speed of gol
wire play; //pauses/plays gol
wire reset; //reset for gol
assign reset = ~KEY[0]; //tied to KEY0
assign LEDG[0] = ~KEY[0]; 
wire m4k_out; //data out of the SM to the m4k
wire m4k_in; //data into the SM from the m4k
wire m4k_we; //m4k we (port a)
wire [18:0] m4k_addr; //address for reading/writing
wire [3:0] obj; //new object to be drawn on the screen

//Game of Life state machine
GameOfLife gol(
	.obj(obj),
	.cur_x(cur_x),
	.cur_y(cur_y),
	.play(play),
	.CLK(VGA_CTRL_CLK),
	.reset(reset),
	.xmax(xmax),
	.xmin(xmin),
	.ymax(ymax),
	.ymin(ymin),
	.vga_x(Coord_X),
	.vga_y(Coord_Y),
	.mem_in(m4k_out),
	.update_period(period_gol),
	.mem_out(m4k_in),
	.mem_we(m4k_we),
	.mem_addr(m4k_addr)
);

//////////////////// DDS Audio ////////////////////
//DDS 0, plays a tones for scan bar 0 (triggered form PlayRowSound0 module)
wire [9:0] st_val0; //value from sine table
wire [7:0] st_sel0; //index into sine table
wire [15:0] audio_out0; //audio output 
wire [3:0] tone_sel0; //selects tone
wire [1:0] speed0; //sets the speed (length) of playback
wire set_sel0; //sets either a high or low octave for the tones played
DDS dds0(
	.update(play_sound0), 
	.CLK(VGA_CTRL_CLK), 
	.audio_CLK(AUD_DACLRCK), 
	.out(audio_out0), 
	.st_sel(st_sel0),
	.tone_sel(tone_sel0),
	.st_val(st_val0),
	.speed_sel(speed0),
	.set_sel(set_sel0)
);

//sine lookup table for scan bar 0
sync_rom sr0(
	.clock(VGA_CTRL_CLK), 
	.address(st_sel0), 
	.sine(st_val0)
	);

//DDS 1, plays a tones for scan bar 1 (triggered form PlayRowSound1 module)
//see labeling above
wire [9:0] st_val1;
wire [7:0] st_sel1;
wire [15:0] audio_out1;
wire [3:0] tone_sel1;
wire [1:0] speed1;
wire set_sel1;
DDS dds1(
	.update(play_sound1), 
	.CLK(VGA_CTRL_CLK), 
	.audio_CLK(AUD_DACLRCK), 
	.out(audio_out1), 
	.st_sel(st_sel1),
	.tone_sel(tone_sel1),
	.st_val(st_val1),
	.speed_sel(speed1),
	.set_sel(set_sel1)
);

//sine lookup table for scan bar 1
sync_rom sr1(
	.clock(VGA_CTRL_CLK), 
	.address(st_sel1), 
	.sine(st_val1)
	);

//DDS 2, plays a tones for scan bar 2 (triggered form PlayRowSound2 module)
//see labeling above
wire [9:0] st_val2;
wire [7:0] st_sel2;
wire [15:0] audio_out2;
wire [3:0] tone_sel2;
wire [1:0] speed2;
wire set_sel2;
DDS dds2(
	.update(play_sound2), 
	.CLK(VGA_CTRL_CLK), 
	.audio_CLK(AUD_DACLRCK), 
	.out(audio_out2), 
	.st_sel(st_sel2),
	.tone_sel(tone_sel2),
	.st_val(st_val2),
	.speed_sel(speed2),
	.set_sel(set_sel2)
);

//sine lookup table for scan bar 2
sync_rom sr2(
	.clock(VGA_CTRL_CLK), 
	.address(st_sel2), 
	.sine(st_val2)
	);

//Combine Audio Signals from 3 scan lines
//Shift each by 2 (divide by 4) and then add
wire [15:0] audio_out;
assign audio_out = {{2{audio_out0[15]}},audio_out0[15:2]}+{{2{audio_out1[15]}},audio_out1[15:2]}+{{2{audio_out2[15]}},audio_out2[15:2]};
	
assign	AUD_ADCLRCK	=	AUD_DACLRCK;
assign	AUD_XCK		=	AUD_CTRL_CLK;

I2C_AV_Config 		u3	(	//	Host Side
						.iCLK(CLOCK_50),
						.iRST_N(KEY[0]),
						//	I2C Side
						.I2C_SCLK(I2C_SCLK),
						.I2C_SDAT(I2C_SDAT)	);

AUDIO_DAC_ADC 			u4	(	//	Audio Side
						.oAUD_BCK(AUD_BCLK),
						.oAUD_DATA(AUD_DACDAT),
						.oAUD_LRCK(AUD_DACLRCK),
						.iAUD_ADCDAT(AUD_ADCDAT),
						.iAUD_extL(audio_out), // audio data to DAC
						.iAUD_extR(audio_out), // audio data to DAC
						//	Control Signals
						.iCLK_18_4(AUD_CTRL_CLK),
						.iRST_N(DLY_RST)
						);
						

//////////////////// Play Row Sound ////////////////////
//Take position of scan bar as input and signal to DDS unit which tone to play
wire play_sound0; //output to DDS module, causing a tone to be played
PlayRowSound prs0(
	.CLK(VGA_CTRL_CLK),
	.reset(reset),
	.vga_y(Coord_Y),
	.vga_x(Coord_X),
	.xmin(xmin),
	.xmax(xmax),
	.row_y(ybar0),
	.ymin(ymin),
	.disp_bit(disp_bit),
	.play_sound(play_sound0),
	.tone_sel(tone_sel0),
	.mode(tone_mode),
	.period(period0)
);

assign LEDR[17] = set_sel0;
assign LEDR[16] = set_sel1;
assign LEDR[15] = set_sel2;

//Take position of scan bar as input and signal to DDS unit which tone to play
wire play_sound1;
PlayRowSound prs1(
	.CLK(VGA_CTRL_CLK),
	.reset(reset),
	.vga_y(Coord_Y),
	.vga_x(Coord_X),
	.xmin(xmin),
	.xmax(xmax),
	.row_y(ybar1),
	.ymin(ymin),
	.disp_bit(disp_bit),
	.play_sound(play_sound1),
	.tone_sel(tone_sel1),
	.mode(tone_mode),
	.period(period1)
);

//Take position of scan bar as input and signal to DDS unit which tone to play
wire play_sound2;
PlayRowSound prs2(
	.CLK(VGA_CTRL_CLK),
	.reset(reset),
	.vga_y(Coord_Y),
	.vga_x(Coord_X),
	.xmin(xmin),
	.xmax(xmax),
	.row_y(ybar2),
	.ymin(ymin),
	.disp_bit(disp_bit),
	.play_sound(play_sound2),
	.tone_sel(tone_sel2),
	.mode(tone_mode),
	.period(period2)
);
	
endmodule 
/************************************* END TOP MODULE ***********************************/

////////// end of file //////////////////////////
