//////////////////// MODULE DEFINITION: Make Cursor ////////////////////
//Takes in raw VGA signals and adds a cursor at the location specified by cur_x,cur_y
module MakeCursor (
//VGA controller position
input [9:0] vga_x,
input [9:0] vga_y,

//cursor position
input [9:0] cur_x,
input [9:0] cur_y,

//raw VGA input signals
input [9:0] mVGA_R,
input [9:0] mVGA_G,
input [9:0] mVGA_B,

//VGA output signal (with cursor added)
output [9:0] mVGA_Rc,
output [9:0] mVGA_Gc,
output [9:0] mVGA_Bc
);	
	
	//A cursor has 4 rays extending out from its center, each perpendicular to one another
	//Draw these pixels instead if the VGA controller is currently asking for this location
	assign mVGA_Rc = ((vga_x[9:0] >= (cur_x-10'd4)) & (vga_x[9:0] <= (cur_x+10'd4)) & (vga_y[9:0] == cur_y)) | 
	((vga_y[9:0] >= (cur_y-10'd4)) & (vga_y[9:0] <= (cur_y+10'd4)) & (vga_x[9:0] == cur_x)) ? 10'd1023 : mVGA_R;
	
	assign mVGA_Gc = ((vga_x[9:0] >= (cur_x-10'd4)) & (vga_x[9:0] <= (cur_x+10'd4)) & (vga_y[9:0] == cur_y)) | 
	((vga_y[9:0] >= (cur_y-10'd4)) & (vga_y[9:0] <= (cur_y+10'd4)) & (vga_x[9:0] == cur_x)) ? 10'd0 : mVGA_G;
	
	assign mVGA_Bc = ((vga_x[9:0] >= (cur_x-10'd4)) & (vga_x[9:0] <= (cur_x+10'd4)) & (vga_y[9:0] == cur_y)) | 
	((vga_y[9:0] >= (cur_y-10'd4)) & (vga_y[9:0] <= (cur_y+10'd4)) & (vga_x[9:0] == cur_x)) ? 10'd0 : mVGA_B;
	
endmodule