//////////////////// MODULE DEFINITION: Make Scan Bar ////////////////////
//This module takes in the raw VGA signal and adds a scan bar on top of it
//The speed is specified by period and the current location of the bar is output on ybar
module MakeScanBar(
input CLK,
input reset,
input en, //enable 
input [23:0] period, //controls scanning speed
input [2:0] mode, //used to "freeze" bars in place

//VGA controller position
input [9:0] vga_y, 
input [9:0] vga_x,

//screen boundaries
input [7:0] xmax,
input [7:0] xmin,
input [6:0] ymax,
input [6:0] ymin,

//raw VGA signals
input [9:0] mVGA_R,
input [9:0] mVGA_G,
input [9:0] mVGA_B,

//define color of the bar drawn
input [9:0] barR,
input [9:0] barG,
input [9:0] barB,

//output VGA signal with the bar included
output [9:0] mVGA_Rs,
output [9:0] mVGA_Gs,
output [9:0] mVGA_Bs,

//current position of the bar 
output [8:0] ybar
);	
	assign ybar = ybarR;

	//highlight the entire row of pixels within the screen boundaries, for the row in which ybar currently resides
	assign mVGA_Rs = (en) ? (((vga_y[8:0]==ybar) & (vga_x[9:2]>=xmin) & (vga_x[9:2]<xmax)) ? barR : mVGA_R) : mVGA_R;
	assign mVGA_Gs = (en) ? (((vga_y[8:0]==ybar) & (vga_x[9:2]>=xmin) & (vga_x[9:2]<xmax)) ? barG : mVGA_G) : mVGA_G;
	assign mVGA_Bs = (en) ? (((vga_y[8:0]==ybar) & (vga_x[9:2]>=xmin) & (vga_x[9:2]<xmax)) ? barB : mVGA_B) : mVGA_B;
	
	reg [23:0] count;
	reg [8:0] ybarR;
	
	always @ (posedge CLK) begin
	
	if (reset | ~en) begin
		//initialize the row and counter
		count <= 24'b0;
		ybarR <= {ymin-7'd1,2'b0};
	end
	
	else begin
		if ((mode!=3'd3) & (mode!=3'd4)) begin
		//if the bars are not "frozen" then add 1 to their row each time the counter reaches the specified period
			if (count == period) begin
				count <= 24'b0;
				if (ybarR < {ymax,2'b0}) ybarR <= ybarR + 9'b1;
				else ybarR <= {ymin,2'b0};
			end
			else count <= count + 24'b1;
		end
	end
	
	end
	
endmodule